==> cfg_e5_2_30_w5_2_71.tar: cfg_e/js/js/tabs/display.js <==
// Котроль отображения вкладок
function permissionTabsShow(model) {
  menuHide();
  if (DEVICEINFO[DEVICEMODEL]) {
    let permission = DEVICEINFO[DEVICEMODEL].tabs; //список доступных вкладок

    for (var i = 0; permission.length > i; i++) {
      if (permission[i] === "tab_gsm_call_pk4" && (THIS_DEVICE.model === 'J6422' || THIS_DEVICE.model === 'J6423')) {
        if (verElestaToInt('1.0w') <= verElestaToInt(currentCoreVersion)) {
          $.show("." + permission[i]);
          continue
        } else {
          continue
        }
      }
      $.show("." + permission[i]);
    }
    display_Local_Distans(); // отображаем локальное или удаленное меню конфигуратора
  } else {
    //alert("Модель прибора " + model + " - не поддерживается конфигуратором");
  }
}

function permissionTabsHide(model) {
  if (DEVICEINFO[DEVICEMODEL]) {
    let permission = DEVICEINFO[DEVICEMODEL].tabs; //список доступных вкладок
    for (var i = 0; permission.length > i; i++) {
      $.hide("." + permission[i]);
    }

  } else {
    //alert("Модель прибора " + model + " - не поддерживается конфигуратором");
  }
  document.location.reload()
}

function menuHide() {
  let arr = document.getElementsByClassName("w3_bar_alltabs");
  for (var i = 0; i < arr.length; i++) {
    arr[i].style.display = "none";
  }
}
function scroll() {
  window.addEventListener('scroll', myFunctionForSticky)
  const navbar = document.getElementById('myHeader')
  const sticky = navbar.offsetTop

  function myFunctionForSticky() {
    if (window.pageYOffset >= sticky) {
      navbar.classList.add('stick')
    } else {
      navbar.classList.remove('stick')
    }
  }
}

function resizeRkpsDiv() {
  if (box_rkps_tlmtr_HEIGHT != "100%") {
    box_rkps_tlmtr_HEIGHT = "100%";
    document.getElementById("box_rkps_tlmtr").style.height = "10%";
    document.getElementById("change").innerHTML = "Свернуть";
    scroll()
  } else {
    rollUp()
  }

}
function rollUp() {
  box_rkps_tlmtr_HEIGHT = "350px";
  if (document.getElementById("box_rkps_tlmtr")) {
    document.getElementById("box_rkps_tlmtr").style.height = "350px";
    document.getElementById("change").innerHTML = "Развернуть";
  }

}
function scrollDownPage() {
  var scrollingElement = document.scrollingElement || document.body;
  scrollingElement.scrollTop = scrollingElement.scrollHeight;
}
function scrollUpPage() {
  var scrollingElement = document.scrollingElement || document.body;
  scrollingElement.scrollTop = 0;
}

==> cfg_e5_2_33_w5_2_75.tar: cfg_e/js/js/tabs/display.js <==
// Котроль отображения вкладок
function permissionTabsShow(model) {
  menuHide();
  if (DEVICEINFO[DEVICEMODEL]) {
    let permission = DEVICEINFO[DEVICEMODEL].tabs; //список доступных вкладок
    /*  let ie = false
     for (i in deviceJSON.config) {
       if (deviceJSON.config[i].key.indexOf("ie") != -1) {
         ie = true
       }
     } */
    for (var i = 0; permission.length > i; i++) {
      if (permission[i] === "tab_gsm_call_pk4" && (DEVICEMODEL === 'J6422' || DEVICEMODEL === 'J6423')) {
        if (verElestaToInt('1.0w') <= verElestaToInt(currentCoreVersion)) {
          $.show("." + permission[i]);
          continue
        } else {
          continue
        }
      }
      /*    if (permission[i] === "tab_ethernet" && !ie) {
           continue
         } */

      $.show("." + permission[i]);
    }
    display_Local_Distans(); // отображаем локальное или удаленное меню конфигуратора
  } else {
    //alert("Модель прибора " + model + " - не поддерживается конфигуратором");
  }
}

function permissionTabsHide(model) {
  if (DEVICEINFO[DEVICEMODEL]) {
    let permission = DEVICEINFO[DEVICEMODEL].tabs; //список доступных вкладок
    for (var i = 0; permission.length > i; i++) {
      $.hide("." + permission[i]);
    }

  } else {
    //alert("Модель прибора " + model + " - не поддерживается конфигуратором");
  }
  document.location.reload()
}

function menuHide() {
  let arr = document.getElementsByClassName("w3_bar_alltabs");
  for (var i = 0; i < arr.length; i++) {
    arr[i].style.display = "none";
  }
}
function scroll() {
  window.addEventListener('scroll', myFunctionForSticky)
  const navbar = document.getElementById('myHeader')
  const sticky = navbar.offsetTop

  function myFunctionForSticky() {
    if (window.pageYOffset >= sticky) {
      navbar.classList.add('stick')
    } else {
      navbar.classList.remove('stick')
    }
  }
}

function resizeRkpsDiv() {
  if (box_rkps_tlmtr_HEIGHT != "100%") {
    box_rkps_tlmtr_HEIGHT = "100%";
    document.getElementById("box_rkps_tlmtr").style.height = "10%";
    document.getElementById("change").innerHTML = "Свернуть";
    scroll()
  } else {
    rollUp()
  }

}
function rollUp() {
  box_rkps_tlmtr_HEIGHT = "350px";
  if (document.getElementById("box_rkps_tlmtr")) {
    document.getElementById("box_rkps_tlmtr").style.height = "350px";
    document.getElementById("change").innerHTML = "Развернуть";
  }

}
function scrollDownPage() {
  var scrollingElement = document.scrollingElement || document.body;
  scrollingElement.scrollTop = scrollingElement.scrollHeight;
}
function scrollUpPage() {
  var scrollingElement = document.scrollingElement || document.body;
  scrollingElement.scrollTop = 0;
}
